abjadbooktools.AbjadBookScript
==============================

.. inheritance-diagram:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript
   :private-bases:

.. autoclass:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.alias

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.long_description

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.output_formats

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.scripting_group

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.short_description

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.version

Methods
-------

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.process_args

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.abjadbooktools.AbjadBookScript.AbjadBookScript.AbjadBookScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
